public inbox for insight@sourceware.org
 help / color / mirror / Atom feed
From: Tom Tromey <tromey@cygnus.com>
To: spolk@redhat.com
Cc: Insight List <insight@sourceware.cygnus.com>
Subject: Re: Patch: fixlet in gdbtk-cmds.c
Date: Wed, 29 Nov 2000 13:48:00 -0000	[thread overview]
Message-ID: <87k89mzbix.fsf@creche.cygnus.com> (raw)
In-Reply-To: <3A245282.C01BFEE6@redhat.com>

Syd> I would rather have a global variable for whether a gdbtk command
Syd> generated the error as opposed to Tcl itself rather than messing
Syd> with interp result flags. This is just asking to break when the
Syd> interp data structure is changed.

I looked at this a bit more.

In the code I quoted `result_ptr' is a global variable like that.
This isn't the intepreter or the result.

I think this patch does what I want:

2000-11-29  Tom Tromey  <tromey@cygnus.com>

	* gdbtk-cmds.c (call_wrapper): Don't reset result if wrapped
	command returned error.

Unfortunately, it is unclear what negative ramifications, if any, this
patch might have.  I'd have to consider it "dangerous".

Syd> I will examine this more in a couple of weeks.

I won't be working on Insight at that point.

Tom

Index: gdbtk-cmds.c
===================================================================
RCS file: /cvs/src/src/gdb/gdbtk/generic/gdbtk-cmds.c,v
retrieving revision 1.12
diff -u -r1.12 gdbtk-cmds.c
--- gdbtk-cmds.c	2000/07/25 20:41:07	1.12
+++ gdbtk-cmds.c	2000/11/29 21:46:36
@@ -459,6 +485,7 @@
 {
   struct wrapped_call_args wrapped_args;
   gdbtk_result new_result, *old_result_ptr;
+  int wrapped_returned_error = 0;
 
   old_result_ptr = result_ptr;
   result_ptr = &new_result;
@@ -497,16 +524,24 @@
       Tcl_Eval (interp, "gdbtk_tcl_idle");
 
     }
+  else
+    {
+      /* If the wrapped call returned an error directly, then we don't
+	 want to reset the result.  */
+      wrapped_returned_error = wrapped_args.val == TCL_ERROR;
+    }
 
   /* do not suppress any errors -- a remote target could have errored */
   load_in_progress = 0;
 
   /*
    * Now copy the result over to the true Tcl result.  If GDBTK_TO_RESULT flag
    * bit is set , this just copies a null object over to the Tcl result, 
    * which is fine because we should reset the result in this case anyway.
    */
-  if (result_ptr->flags & GDBTK_IN_TCL_RESULT)
+  if ((result_ptr->flags & GDBTK_IN_TCL_RESULT) || wrapped_returned_error)
     {
       Tcl_DecrRefCount (result_ptr->obj_ptr);
     }
@@ -580,8 +615,10 @@
      Tcl_Obj *CONST objv[];
 {
   if (objc != 1)
-    Tcl_SetStringObj (result_ptr->obj_ptr,
-		      "Wrong number of args, none are allowed.", -1);
+    {
+      Tcl_WrongNumArgs (interp, 1, objv, NULL);
+      return TCL_ERROR;
+    }
 
   if (inferior_pid != 0 && target_has_execution)
     {
@@ -497,16 +524,24 @@
 
   /*
-   * Now copy the result over to the true Tcl result.  If GDBTK_TO_RESULT flag
-   * bit is set , this just copies a null object over to the Tcl result, 
-   * which is fine because we should reset the result in this case anyway.
+   * Now copy the result over to the true Tcl result.  If
+   * GDBTK_TO_RESULT flag bit is set, this just copies a null object
+   * over to the Tcl result, which is fine because we should reset the
+   * result in this case anyway.  If the wrapped command returned an
+   * error, then we assume that the result is already set correctly.
    */

  reply	other threads:[~2000-11-29 13:48 UTC|newest]

Thread overview: 27+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2000-11-28 10:34 Tom Tromey
2000-11-28 12:55 ` Syd Polk
2000-11-28 13:46   ` Tom Tromey
2000-11-28 14:47     ` Syd Polk
2000-11-28 17:32   ` Tom Tromey
2000-11-28 23:51     ` Syd Polk
2000-11-29 13:48       ` Tom Tromey [this message]
2000-11-29 18:41         ` Syd Polk
2000-11-29 20:07           ` Fernando Nasser
2000-11-30  9:09             ` Tom Tromey
2000-11-30  9:57               ` Fernando Nasser
     [not found] <Syd>
     [not found] ` <Polk's>
     [not found]   ` <message>
     [not found]     ` <of>
     [not found]       ` <"Tue,>
     [not found]       ` <"28>
     [not found]       ` <"Wed,>
     [not found]       ` <"Mon,>
     [not found]         ` <01>
     [not found]           ` <May>
     [not found]             ` <2000>
     [not found]               ` <09:07:18>
     [not found]                 ` <-0700>
2000-04-29  7:21                   ` make check in itcl Andreas Jaeger
2000-05-01  9:05                     ` Syd Polk
2000-05-01  9:27                       ` Andreas Jaeger
2000-05-01 10:15                         ` Syd Polk
2000-05-01 10:58                           ` Andreas Jaeger
2000-05-01 11:21                             ` Syd Polk
2000-05-03 10:37                             ` Syd Polk
2000-05-03 12:05                               ` Andreas Jaeger
2000-05-03 12:37                                 ` Syd Polk
2000-05-04  2:34                                   ` Andrew Cagney
     [not found]               ` <09:17:35>
     [not found]                 ` <-0800>
2000-11-21 16:03                   ` rename to insight Tom Tromey
     [not found]                     ` <mailpost.974851789.4627@postal.sibyte.com>
2000-11-22  9:42                       ` Chris G. Demetriou
2000-11-22 10:29                         ` Tom Tromey
2000-11-28  9:18                           ` Chris G. Demetriou
2000-11-28  9:34                             ` Tom Tromey
2000-11-28 12:52                               ` Syd Polk

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=87k89mzbix.fsf@creche.cygnus.com \
    --to=tromey@cygnus.com \
    --cc=insight@sourceware.cygnus.com \
    --cc=spolk@redhat.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).